@@ -13,7 +13,7 @@
 # limitations under the License.
 
 import json
-from typing import Dict, List, Optional, Tuple, Type, Union
+from typing import Any, Dict, List, Optional, Tuple, Type, Union
 
 import numpy
 import onnx
@@ -168,7 +168,9 @@ class YOLOPipeline(Pipeline):
             )
         return model_path
 
-    def process_inputs(self, inputs: YOLOInput) -> List[numpy.ndarray]:
+    def process_inputs(
+        self, inputs: YOLOInput
+    ) -> Tuple[List[numpy.ndarray], Dict[str, Any]]:
         """
         :param inputs: inputs to the pipeline. Must be the type of the `input_schema`
             of this pipeline
@@ -181,22 +183,7 @@ class YOLOPipeline(Pipeline):
         if isinstance(inputs.images, (str, numpy.ndarray)):
             inputs.images = [inputs.images]
 
-        image_batch = []
-
-        for image in inputs.images:
-            if isinstance(image, list):
-                # image consists of floats or ints
-                image = numpy.asarray(image)
-
-            if isinstance(image, str):
-                image = cv2.imread(image)
-
-            image = self._make_channels_last(image)
-            if image.ndim < 4:
-                # Assume a batch is of the correct size already
-                image = cv2.resize(image, dsize=tuple(reversed(self.image_size)))
-            image = self._make_channels_first(image)
-            image_batch.append(image)
+        image_batch = list(self.executor.map(self._preprocess_image, inputs.images))
 
         image_batch = self._make_batch(image_batch)
         image_batch = numpy.ascontiguousarray(
@@ -209,9 +196,25 @@ class YOLOPipeline(Pipeline):
         postprocessing_kwargs = dict(
             iou_thres=inputs.iou_thres,
             conf_thres=inputs.conf_thres,
+            multi_label=inputs.multi_label,
         )
         return [image_batch], postprocessing_kwargs
 
+    def _preprocess_image(self, image) -> numpy.ndarray:
+        if isinstance(image, list):
+            # image consists of floats or ints
+            image = numpy.asarray(image)
+
+        if isinstance(image, str):
+            image = cv2.imread(image)
+
+        image = self._make_channels_last(image)
+        if image.ndim < 4:
+            # Assume a batch is of the correct size already
+            image = cv2.resize(image, dsize=tuple(reversed(self.image_size)))
+        image = self._make_channels_first(image)
+        return image
+
     def process_engine_outputs(
         self,
         engine_outputs: List[numpy.ndarray],
@@ -237,12 +240,12 @@ class YOLOPipeline(Pipeline):
             batch_output,
             iou_thres=kwargs.get("iou_thres", 0.25),
             conf_thres=kwargs.get("conf_thres", 0.45),
+            multi_label=kwargs.get("multi_label", False),
         )
 
-        batch_predictions, batch_boxes, batch_scores, batch_labels = [], [], [], []
+        batch_boxes, batch_scores, batch_labels = [], [], []
 
         for image_output in batch_output:
-            batch_predictions.append(image_output.tolist())
             batch_boxes.append(image_output[:, 0:4].tolist())
             batch_scores.append(image_output[:, 4].tolist())
             batch_labels.append(image_output[:, 5].tolist())
@@ -257,7 +260,6 @@ class YOLOPipeline(Pipeline):
                 batch_labels[-1] = batch_class_names
 
         return YOLOOutput(
-            predictions=batch_predictions,
             boxes=batch_boxes,
             scores=batch_scores,
             labels=batch_labels,
